netapp_ontap.models.key_server_readcreate API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.key_server_readcreate`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class KeyServerReadcreateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the KeyServerReadcreate object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the key_server_readcreate.

  `secondary_key_servers GET POST PATCH`

    A list of the secondary key servers associated with the primary key server.

  `server GET POST`

    External key server for key management. If no port is provided, a default port of 5696 is used.

    Example: keyserver1.com:5698

  `timeout GET`

    I/O timeout in seconds for communicating with the key server.

    Example: 60

  `username GET`

    Username credentials for connecting with the key server.

    Example: admin